@@ -2,6 +2,7 @@
 
 from dataclasses import dataclass
 from typing import Optional, Union
+from uuid import UUID, uuid4
 
 from serde import ExternalTagging, field, serde
 
@@ -41,6 +42,7 @@ class Task:
     rejuvenation: Union[int, float] = 1.0
     duration: Union[int, float] = 1.0
     cost: Union[int, float] = 1.0
+    uuid: UUID = field(default_factory=uuid4)
 
 
 @serde
@@ -57,6 +59,7 @@ class Maintenance:
     name: Optional[str] = field(default=None, skip_if_default=True)
     task: Task = field(default_factory=Task)
     time: Union[int, float] = 1.0
+    uuid: UUID = field(default_factory=uuid4)
 
     @property
     def end(self) -> Union[int, float]:
@@ -82,7 +85,10 @@ class Component:
     distribution: distributions.Distributions = field(
         default_factory=distributions.Weibull
     )
-    maintenance: list[Maintenance] = field(default_factory=list, skip_if=_is_empty)
+    maintenance: list[Maintenance] = field(
+        default_factory=list, skip_if=_is_empty, repr=False
+    )
+    uuid: UUID = field(default_factory=uuid4)
 
     def get_ordered_maintenance(self) -> list[Maintenance]:
         """Maintenance tasks sorted in time."""
@@ -128,7 +134,10 @@ class System:
     """
 
     name: Optional[str] = field(default=None, skip_if_default=True)
-    components: list[Component] = field(default_factory=list, skip_if=_is_empty)
+    components: list[Component] = field(
+        default_factory=list, skip_if=_is_empty, repr=False
+    )
+    uuid: UUID = field(default_factory=uuid4)
 
     def cfp(self, x: Union[int, float] = 1.0) -> float:
         """Cumulative failure probability density function as the sum of its
@@ -182,6 +191,7 @@ class Horizon:
 
     start: Union[int, float] = 0.0
     end: Optional[Union[int, float]] = field(default=None, skip_if_default=True)
+    uuid: UUID = field(default_factory=uuid4)
 
     def get_range(self, steps: int, zero_based: bool = True) -> list[Union[int, float]]:
         """Range between start and end (inclusive) in the given number of steps."""
@@ -199,7 +209,8 @@ class Project:
 
     name: Optional[str] = field(default=None, skip_if_default=True)
     horizon: Horizon = field(default_factory=Horizon)
-    systems: list[System] = field(default_factory=list, skip_if=_is_empty)
+    systems: list[System] = field(default_factory=list, skip_if=_is_empty, repr=False)
+    uuid: UUID = field(default_factory=uuid4)
 
     def get_horizon_end(self) -> float:
         """Get the end of the planning horizon or last maintenance task."""
@@ -266,14 +277,17 @@ class Project:
     def get_schedule(self) -> "Schedule":
         """Get a fully generated schedule."""
         return Schedule(
-            tasks=[
+            items=[
                 ScheduleItem(
-                    m.task.name,
+                    name=m.task.name,
+                    project=self.name,
+                    system=s.name,
+                    component=c.name,
+                    maintenance=m.name,
+                    task=m.task.name,
                     rejuvenation=m.task.rejuvenation,
                     duration=m.task.duration,
                     cost=m.task.cost,
-                    system=s.name,
-                    component=c.name,
                     time=m.time,
                 )
                 for s in self.systems
@@ -301,12 +315,16 @@ class ScheduleItem:
     """
 
     name: Optional[str] = field(default=None, skip_if_default=True)
+    project: Optional[str] = field(default=None, skip_if_default=True)
+    system: Optional[str] = field(default=None, skip_if_default=True)
+    component: Optional[str] = field(default=None, skip_if_default=True)
+    maintenance: Optional[str] = field(default=None, skip_if_default=True)
+    task: Optional[str] = field(default=None, skip_if_default=True)
     rejuvenation: Union[int, float] = 1.0
     duration: Union[int, float] = 1.0
     cost: Union[int, float] = 1.0
-    system: Optional[str] = field(default=None, skip_if_default=True)
-    component: Optional[str] = field(default=None, skip_if_default=True)
-    time: Union[str, float] = 1.0
+    time: Union[int, float] = 1.0
+    uuid: UUID = field(default_factory=uuid4)
 
 
 @serde
@@ -315,11 +333,18 @@ class Schedule:
     """A full maintenance schedule.
 
     Arguments:
-        tasks: Scheduled tasks.
+        items: Scheduled tasks.
     """
 
-    tasks: list[ScheduleItem] = field(default_factory=list, skip_if=_is_empty)
+    items: list[ScheduleItem] = field(default_factory=list, skip_if=_is_empty)
 
     def get_ordered_maintenance(self) -> list[ScheduleItem]:
         """Get all tasks ordered in time."""
-        return sorted(self.tasks, key=lambda t: t.time)
+        return sorted(self.items, key=lambda t: t.time)
+
+    @classmethod
+    def from_projects(cls, projects: list[Project]) -> "Schedule":
+        """Create a schedule for multiple projects."""
+
+        schedules = [p.get_schedule() for p in projects]
+        return cls(items=[i for s in schedules for i in s.items])
